@@ -1,6 +1,7 @@
 mod any;
 mod arc;
 mod boolean;
+mod box_any;
 mod closure;
 pub mod cps;
 mod none;
@@ -10,6 +11,7 @@ mod string;
 pub use any::*;
 pub use arc::*;
 pub use boolean::*;
+pub use box_any::*;
 pub use closure::*;
 pub use none::*;
 pub use number::*;
